'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = undefined;

var _neoBlockchainCore = require('neo-blockchain-core');

let ConsensusPayload = class ConsensusPayload {

  constructor({
    version,
    previousHash,
    blockIndex,
    validatorIndex,
    timestamp,
    data,
    script
  }) {
    this.serializeWire = (0, _neoBlockchainCore.createSerializeWire)(this.serializeWireBase.bind(this));

    this.version = version;
    this.previousHash = previousHash;
    this.blockIndex = blockIndex;
    this.validatorIndex = validatorIndex;
    this.timestamp = timestamp;
    this.data = data;
    this.script = script;
  }

  serializeWireBase(writer) {
    writer.writeUInt32LE(this.version);
    writer.writeUInt256(this.previousHash);
    writer.writeUInt32LE(this.blockIndex);
    writer.writeUInt16LE(this.validatorIndex);
    writer.writeUInt32LE(this.timestamp);
    writer.writeVarBytesLE(this.data);
    writer.writeUInt8(1);
    this.script.serializeWireBase(writer);
  }

  static deserializeWireBase(options) {
    const { reader } = options;
    const version = reader.readUInt32LE();
    const previousHash = reader.readUInt256();
    const blockIndex = reader.readUInt32LE();
    const validatorIndex = reader.readUInt16LE();
    const timestamp = reader.readUInt32LE();
    const data = reader.readVarBytesLE();
    if (reader.readUInt8() !== 1) {
      throw new _neoBlockchainCore.InvalidFormatError();
    }
    const script = _neoBlockchainCore.Witness.deserializeWireBase(options);

    return new this({
      version,
      previousHash,
      blockIndex,
      validatorIndex,
      timestamp,
      data,
      script
    });
  }

  static deserializeWire(options) {
    return this.deserializeWireBase({
      context: options.context,
      reader: new _neoBlockchainCore.BinaryReader(options.buffer)
    });
  }
};
exports.default = ConsensusPayload;